@@ -135,14 +135,6 @@ class FADNProductRelation(BaseModel):
     productGroupId: Optional[int] = None
     fadnProductId: Optional[int] = None
     populationId: Optional[int] = None
-    # The representativeness of the FADN product in the product group. Item representativeness should be calculated
-    # as the representativeness of the FADN product divided by the sum of the representativeness of all FADN products in the product group.
-    # For its calculation, remember than whe obtaining data from the sample, the weight of such farm in the population should be taken into account
-    representativenessOcurrence: Optional[float] = None
-    # In hectars
-    representativenessArea: Optional[float] = None
-    # In €
-    representativenessValue: Optional[float] = None
 
 class ClosingValue(BaseModel):
     id: Optional[int] = None
@@ -391,6 +383,7 @@ class AgroManagementDecisionFromLP(BaseModel):
 class DataToLPDTO(BaseModel):
     values: List[ValueToLPDTO]
     agriculturalProductions: List[AgriculturalProductionDTO]
+    policyGroupRelations: List[PolicyGroupRelationJsonDTO]
     ignoreLP: Optional[bool]
     ignoreLMM: Optional[bool]
 
