@@ -13,6 +13,14 @@ class FADNProductJsonDTO(BaseModel):
     description: str
     productType: str
     arable: bool
+    # The representativeness of the FADN product in the product group. Item representativeness should be calculated
+    # as the representativeness of the FADN product divided by the sum of the representativeness of all FADN products in the product group.
+    # For its calculation, remember than whe obtaining data from the sample, the weight of such farm in the population should be taken into account
+    representativenessOcurrence: Optional[float] = None
+    # In hectars
+    representativenessArea: Optional[float] = None
+    # In €
+    representativenessValue: Optional[float] = None
     
 class PolicyJsonDTO(BaseModel):
     populationId: int
